@@ -23,7 +23,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 // Qt
 #include <QAction>
+#include <QApplication>
+#include <QClipboard>
+#include <QListView>
 #include <QMenu>
+#include <QMimeData>
 
 // KDE
 #include <kaction.h>
@@ -31,6 +35,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #include <kactioncategory.h>
 #include <kdebug.h>
 #include <kfileitem.h>
+#include <kfileitemlistproperties.h>
+#include <kio/paste.h>
 #include <klocale.h>
 #include <kmimetypetrader.h>
 #include <kopenwithdialog.h>
@@ -46,12 +52,61 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 namespace Gwenview {
 
+// copied from libkonq (konqmimedata.cpp)
+static const char* CUT_SELECTION_DATA = "application/x-kde-cutselection";
+
+static void addCutSelection(QMimeData* mimeData) {
+	mimeData->setData(CUT_SELECTION_DATA, "1");
+}
+
+static bool decodeIsCutSelection(const QMimeData* mimeData) {
+	QByteArray data = mimeData->data(CUT_SELECTION_DATA);
+	return data.isEmpty() ? false : data.at(0) == '1';
+}
+
+// copied from libkonq (konq_operations.cpp)
+static QPair<bool, QString> pasteInfo(const KUrl& targetUrl) {
+    QPair<bool, QString> ret;
+    QClipboard* clipboard = QApplication::clipboard();
+    const QMimeData* mimeData = clipboard->mimeData();
+
+    const bool canPasteData = KIO::canPasteMimeSource(mimeData);
+    KUrl::List urls = KUrl::List::fromMimeData(mimeData);
+    if (!urls.isEmpty() || canPasteData) {
+        // disable the paste action if no writing is supported
+        KFileItem item(KFileItem::Unknown, KFileItem::Unknown, targetUrl);
+        ret.first = KFileItemListProperties(KFileItemList() << item).supportsWriting();
+
+        if (urls.count() == 1) {
+            const KFileItem item(KFileItem::Unknown, KFileItem::Unknown, urls.first(), true);
+            ret.second = item.isDir() ? i18nc("@action:inmenu", "Paste One Folder") :
+                                        i18nc("@action:inmenu", "Paste One File");
+
+        } else if (!urls.isEmpty()) {
+            ret.second = i18ncp("@action:inmenu", "Paste One Item", "Paste %1 Items", urls.count());
+        } else {
+            ret.second = i18nc("@action:inmenu", "Paste Clipboard Contents...");
+        }
+    } else {
+        ret.first = false;
+        ret.second = i18nc("@action:inmenu", "Paste");
+    }
+
+    return ret;
+}
+// /copied
+
 struct FileOpsContextManagerItemPrivate {
 	FileOpsContextManagerItem* mContextManagerItem;
+	QListView* mThumbnailView;
 	SideBarGroup* mGroup;
+	KAction* mCutAction;
+	KAction* mCopyAction;
+	KAction* mPasteAction;
 	KAction* mCopyToAction;
 	KAction* mMoveToAction;
 	KAction* mLinkToAction;
+	KAction* mRenameAction;
 	KAction* mTrashAction;
 	KAction* mDelAction;
 	KAction* mShowPropertiesAction;
@@ -62,7 +117,7 @@ struct FileOpsContextManagerItemPrivate {
 	KUrl::List urlList() const {
 		KUrl::List urlList;
 
-		KFileItemList list = mContextManagerItem->contextManager()->selection();
+		KFileItemList list = mContextManagerItem->contextManager()->selectedFileItemList();
 		if (list.count() > 0) {
 			urlList = list.urlList();
 		} else {
@@ -80,7 +135,7 @@ struct FileOpsContextManagerItemPrivate {
 
 		// Get list of all distinct mimetypes in selection
 		QStringList mimeTypes;
-		Q_FOREACH(const KFileItem& item, mContextManagerItem->contextManager()->selection()) {
+		Q_FOREACH(const KFileItem& item, mContextManagerItem->contextManager()->selectedFileItemList()) {
 			const QString mimeType = item.mimetype();
 			if (!mimeTypes.contains(mimeType)) {
 				mimeTypes << mimeType;
@@ -105,13 +160,34 @@ struct FileOpsContextManagerItemPrivate {
 			mServiceForName[service->name()] = service;
 		}
 	}
+
+
+	QMimeData* selectionMimeData() {
+		QMimeData* mimeData = new QMimeData;
+		KFileItemList list = mContextManagerItem->contextManager()->selectedFileItemList();
+		list.urlList().populateMimeData(mimeData);
+		return mimeData;
+	}
+
+
+	KUrl pasteTargetUrl() const {
+		// If only one folder is selected, paste inside it, otherwise paste in
+		// current
+		KFileItemList list = mContextManagerItem->contextManager()->selectedFileItemList();
+		if (list.count() == 1 && list.first().isDir()) {
+			return list.first().url();
+		} else {
+			return mContextManagerItem->contextManager()->currentDirUrl();
+		}
+	}
 };
 
 
-FileOpsContextManagerItem::FileOpsContextManagerItem(ContextManager* manager, KActionCollection* actionCollection)
+FileOpsContextManagerItem::FileOpsContextManagerItem(ContextManager* manager, QListView* thumbnailView, KActionCollection* actionCollection)
 : AbstractContextManagerItem(manager)
 , d(new FileOpsContextManagerItemPrivate) {
 	d->mContextManagerItem = this;
+	d->mThumbnailView = thumbnailView;
 	d->mGroup = new SideBarGroup(i18n("File Operations"));
 	setWidget(d->mGroup);
 	EventWatcher::install(d->mGroup, QEvent::Show, this, SLOT(updateSideBarContent()));
@@ -121,7 +197,20 @@ FileOpsContextManagerItem::FileOpsContextManagerItem(ContextManager* manager, KA
 	connect(contextManager(), SIGNAL(currentDirUrlChanged()),
 		SLOT(updateActions()) );
 
-	KActionCategory* file=new KActionCategory(i18nc("@title actions category","File"), actionCollection);
+	KActionCategory* file = new KActionCategory(i18nc("@title actions category","File"), actionCollection);
+	KActionCategory* edit = new KActionCategory(i18nc("@title actions category","Edit"), actionCollection);
+
+	d->mCutAction = edit->addAction(KStandardAction::Cut, this, SLOT(cut()));
+
+	// Copied from Dolphin:
+    // need to remove shift+del from cut action, else the shortcut for deletejob
+    // doesn't work
+	KShortcut cutShortcut = d->mCutAction->shortcut();
+	cutShortcut.remove(Qt::SHIFT + Qt::Key_Delete, KShortcut::KeepEmpty);
+	d->mCutAction->setShortcut(cutShortcut);
+
+	d->mCopyAction = edit->addAction(KStandardAction::Copy, this, SLOT(copy()));
+	d->mPasteAction = edit->addAction(KStandardAction::Paste, this, SLOT(paste()));
 
 	d->mCopyToAction = file->addAction("file_copy_to",this,SLOT(copyTo()));
 	d->mCopyToAction->setText(i18nc("Verb", "Copy To..."));
@@ -135,6 +224,10 @@ FileOpsContextManagerItem::FileOpsContextManagerItem(ContextManager* manager, KA
 	d->mLinkToAction->setText(i18nc("Verb: create link to the file where user wants", "Link To..."));
 	d->mLinkToAction->setShortcut(Qt::Key_F9);
 
+	d->mRenameAction = file->addAction("file_rename",this,SLOT(rename()));
+	d->mRenameAction->setText(i18nc("Verb", "Rename..."));
+	d->mRenameAction->setShortcut(Qt::Key_F2);
+
 	d->mTrashAction = file->addAction("file_trash",this,SLOT(trash()));
 	d->mTrashAction->setText(i18nc("Verb", "Trash"));
 	d->mTrashAction->setIcon(KIcon("user-trash"));
@@ -162,6 +255,10 @@ FileOpsContextManagerItem::FileOpsContextManagerItem(ContextManager* manager, KA
 	connect(menu, SIGNAL(triggered(QAction*)),
 		SLOT(openWith(QAction*)) );
 	updateActions();
+
+	connect(QApplication::clipboard(), SIGNAL(dataChanged()),
+		SLOT(updatePasteAction()));
+	updatePasteAction();
 }
 
 
@@ -172,16 +269,20 @@ FileOpsContextManagerItem::~FileOpsContextManagerItem() {
 
 
 void FileOpsContextManagerItem::updateActions() {
-	bool selectionNotEmpty = contextManager()->selection().count() > 0;
+	const int count = contextManager()->selectedFileItemList().count();
+	const bool selectionNotEmpty = count > 0;
 	const bool urlIsValid = contextManager()->currentUrl().isValid();
 	const bool dirUrlIsValid = contextManager()->currentDirUrl().isValid();
 
+	d->mCutAction->setEnabled(selectionNotEmpty);
+	d->mCopyAction->setEnabled(selectionNotEmpty);
 	d->mCopyToAction->setEnabled(selectionNotEmpty);
 	d->mMoveToAction->setEnabled(selectionNotEmpty);
 	d->mLinkToAction->setEnabled(selectionNotEmpty);
 	d->mTrashAction->setEnabled(selectionNotEmpty);
 	d->mDelAction->setEnabled(selectionNotEmpty);
 	d->mOpenWithAction->setEnabled(selectionNotEmpty);
+	d->mRenameAction->setEnabled(count == 1);
 
 	d->mCreateFolderAction->setEnabled(dirUrlIsValid);
 	d->mShowPropertiesAction->setEnabled(dirUrlIsValid || urlIsValid);
@@ -190,6 +291,13 @@ void FileOpsContextManagerItem::updateActions() {
 }
 
 
+void FileOpsContextManagerItem::updatePasteAction() {
+	QPair<bool, QString> info = pasteInfo(d->pasteTargetUrl());
+	d->mPasteAction->setEnabled(info.first);
+	d->mPasteAction->setText(info.second);
+}
+
+
 inline void addIfEnabled(SideBarGroup* group, QAction* action) {
 	if (action->isEnabled()) {
 		group->addAction(action);
@@ -202,19 +310,20 @@ void FileOpsContextManagerItem::updateSideBarContent() {
 	}
 
 	d->mGroup->clear();
-	addIfEnabled(d->mGroup, d->mCreateFolderAction);
+	addIfEnabled(d->mGroup, d->mRenameAction);
+	addIfEnabled(d->mGroup, d->mTrashAction);
+	addIfEnabled(d->mGroup, d->mDelAction);
 	addIfEnabled(d->mGroup, d->mCopyToAction);
 	addIfEnabled(d->mGroup, d->mMoveToAction);
 	addIfEnabled(d->mGroup, d->mLinkToAction);
-	addIfEnabled(d->mGroup, d->mTrashAction);
-	addIfEnabled(d->mGroup, d->mDelAction);
-	addIfEnabled(d->mGroup, d->mOpenWithAction);
 	addIfEnabled(d->mGroup, d->mShowPropertiesAction);
+	addIfEnabled(d->mGroup, d->mCreateFolderAction);
+	addIfEnabled(d->mGroup, d->mOpenWithAction);
 }
 
 
 void FileOpsContextManagerItem::showProperties() {
-	KFileItemList list = contextManager()->selection();
+	KFileItemList list = contextManager()->selectedFileItemList();
 	if (list.count() > 0) {
 		KPropertiesDialog::showDialog(list, d->mGroup);
 	} else {
@@ -224,6 +333,25 @@ void FileOpsContextManagerItem::showProperties() {
 }
 
 
+void FileOpsContextManagerItem::cut() {
+	QMimeData* mimeData = d->selectionMimeData();
+	addCutSelection(mimeData);
+	QApplication::clipboard()->setMimeData(mimeData);
+}
+
+
+void FileOpsContextManagerItem::copy() {
+	QMimeData* mimeData = d->selectionMimeData();
+	QApplication::clipboard()->setMimeData(mimeData);
+}
+
+
+void FileOpsContextManagerItem::paste() {
+	const bool move = decodeIsCutSelection(QApplication::clipboard()->mimeData());
+	KIO::pasteClipboard(d->pasteTargetUrl(), d->mGroup, move);
+}
+
+
 void FileOpsContextManagerItem::trash() {
 	FileOperations::trash(d->urlList(), d->mGroup);
 }
@@ -249,6 +377,16 @@ void FileOpsContextManagerItem::linkTo() {
 }
 
 
+void FileOpsContextManagerItem::rename() {
+	if (d->mThumbnailView->isVisible()) {
+		QModelIndex index = d->mThumbnailView->currentIndex();
+		d->mThumbnailView->edit(index);
+	} else {
+		FileOperations::rename(d->urlList().first(), d->mGroup);
+	}
+}
+
+
 void FileOpsContextManagerItem::createFolder() {
 	KUrl url = contextManager()->currentDirUrl();
 	FileOperations::createFolder(url, d->mGroup);
