@@ -1,7 +1,7 @@
 // vim: set tabstop=4 shiftwidth=4 noexpandtab:
 /*
 Gwenview: an image viewer
-Copyright 2008 Aurélien Gâteau <aurelien.gateau@free.fr>
+Copyright 2008 Aurélien Gâteau <agateau@kde.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -35,7 +35,7 @@ class QDate;
 namespace Gwenview {
 
 
-class DateWidgetPrivate;
+struct DateWidgetPrivate;
 class GWENVIEWLIB_EXPORT DateWidget : public QWidget {
 	Q_OBJECT
 public:
@@ -54,7 +54,7 @@ private Q_SLOTS:
 	void goToNext();
 
 private:
-	friend class DateWidgetPrivate;
+	friend struct DateWidgetPrivate;
 	DateWidgetPrivate* const d;
 };
 
