@@ -28,6 +28,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 // KDE
 #include <kdebug.h>
 #include <kfileitem.h>
+#include <klocale.h>
 #include <kurl.h>
 
 // Local
@@ -224,12 +225,14 @@ void Document::waitUntilLoaded() {
 DocumentJob* Document::save(const KUrl& url, const QByteArray& format) {
 	waitUntilLoaded();
 	DocumentJob* job = d->mImpl->save(url, format);
-	job->setProperty("oldUrl", d->mUrl);
-	job->setProperty("newUrl", url);
 	if (!job) {
 		kWarning() << "Implementation does not support saving!";
+		//NOTE uses a QString here as the strings are already frozen, yet the user should get some feedback
+		setErrorString(QString("Gwenview cannot save this kind of documents."));
 		return false;
 	}
+	job->setProperty("oldUrl", d->mUrl);
+	job->setProperty("newUrl", url);
 	connect(job, SIGNAL(result(KJob*)), SLOT(slotSaveResult(KJob*)));
 	enqueueJob(job);
 	return job;
