@@ -32,10 +32,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 // Local
 #include <lib/document/document.h>
 
-class QSize;
+class QCursor;
 class QWidget;
 
-class KUrl;
 
 namespace Gwenview {
 
@@ -61,6 +60,10 @@ public:
 
 	virtual void installEventFilterOnViewWidgets(QObject*) = 0;
 
+	virtual QCursor cursor() const;
+
+	virtual void setCursor(const QCursor&);
+
 	/**
 	 * @defgroup zooming functions
 	 * @{
