@@ -93,6 +93,7 @@ KLineal::KLineal( QWidget *parent )
 
   setAttribute( Qt::WA_TranslucentBackground );
   setWindowFlags( Qt::FramelessWindowHint );
+  setWindowTitle( i18n( "KRuler" ) );
 
   setMinimumSize( 60, 60 );
   setMaximumSize( 8000, 8000 );
@@ -138,12 +139,12 @@ KLineal::KLineal( QWidget *parent )
                                  "little square at the end of the line cursor." ) );
 
   mBtnRotateLeft = new QToolButton( this );
-  mBtnRotateLeft->setIcon( KIcon( "object-rotate-left" ) );
+  mBtnRotateLeft->setIcon( KIcon( QLatin1String(  "object-rotate-left" ) ) );
   mBtnRotateLeft->setToolTip( i18n( "Turn Left" ) );
   connect( mBtnRotateLeft, SIGNAL( clicked() ), this, SLOT( turnLeft() ) );
 
   mBtnRotateRight = new QToolButton( this );
-  mBtnRotateRight->setIcon( KIcon( "object-rotate-right" ) );
+  mBtnRotateRight->setIcon( KIcon( QLatin1String(  "object-rotate-right" ) ) );
   mBtnRotateRight->setToolTip( i18n( "Turn Right" ) );
   connect( mBtnRotateRight, SIGNAL( clicked() ), this, SLOT( turnRight() ) );
 
@@ -151,51 +152,51 @@ KLineal::KLineal( QWidget *parent )
 
   //BEGIN setup menu and actions
   mActionCollection = new KActionCollection( this );
-  mActionCollection->setConfigGroup( "Actions" );
+  mActionCollection->setConfigGroup( QLatin1String( "Actions" ) );
 
   mMenu = new KMenu( this );
   mMenu->addTitle( i18n( "KRuler" ) );
   KMenu *oriMenu = new KMenu( i18n( "&Orientation"), this );
-  addAction( oriMenu, KIcon( "kruler-north" ), i18nc( "Turn Kruler North", "&North" ),
-             this, SLOT( setNorth() ), Qt::Key_N, "turn_north" );
-  addAction( oriMenu, KIcon( "kruler-east" ), i18nc( "Turn Kruler East", "&East" ),
-             this, SLOT( setEast() ), Qt::Key_E, "turn_east" );
-  addAction( oriMenu, KIcon( "kruler-south" ), i18nc( "Turn Kruler South", "&South" ),
-             this, SLOT( setSouth() ), Qt::Key_S, "turn_south" );
-  addAction( oriMenu, KIcon( "kruler-west" ), i18nc( "Turn Kruler West", "&West" ),
-             this, SLOT( setWest() ), Qt::Key_W, "turn_west" );
-  addAction( oriMenu, KIcon( "object-rotate-right" ), i18n( "&Turn Right" ),
-             this, SLOT( turnRight() ), Qt::Key_R, "turn_right" );
-  addAction( oriMenu, KIcon( "object-rotate-left" ), i18n( "Turn &Left" ),
-             this, SLOT( turnLeft() ), Qt::Key_L, "turn_left" );
+  addAction( oriMenu, KIcon( QLatin1String( "kruler-north" ) ), i18nc( "Turn Kruler North", "&North" ),
+             this, SLOT( setNorth() ), Qt::Key_N, QLatin1String( "turn_north" ) );
+  addAction( oriMenu, KIcon( QLatin1String( "kruler-east" ) ), i18nc( "Turn Kruler East", "&East" ),
+             this, SLOT( setEast() ), Qt::Key_E, QLatin1String( "turn_east" ) );
+  addAction( oriMenu, KIcon( QLatin1String( "kruler-south" ) ), i18nc( "Turn Kruler South", "&South" ),
+             this, SLOT( setSouth() ), Qt::Key_S, QLatin1String( "turn_south" ) );
+  addAction( oriMenu, KIcon( QLatin1String( "kruler-west" ) ), i18nc( "Turn Kruler West", "&West" ),
+             this, SLOT( setWest() ), Qt::Key_W, QLatin1String( "turn_west" ) );
+  addAction( oriMenu, KIcon( QLatin1String( "object-rotate-right" ) ), i18n( "&Turn Right" ),
+             this, SLOT( turnRight() ), Qt::Key_R, QLatin1String( "turn_right" ) );
+  addAction( oriMenu, KIcon( QLatin1String( "object-rotate-left" ) ), i18n( "Turn &Left" ),
+             this, SLOT( turnLeft() ), Qt::Key_L, QLatin1String( "turn_left" ) );
   mMenu->addMenu( oriMenu );
 
   mLenMenu = new KMenu( i18n( "&Length" ), this );
   addAction( mLenMenu, KIcon(), i18nc( "Make Kruler Height Short", "&Short" ),
-             this, SLOT( setShortLength() ), Qt::CTRL + Qt::Key_S, "length_short" );
+             this, SLOT( setShortLength() ), Qt::CTRL + Qt::Key_S, QLatin1String( "length_short" ) );
   addAction( mLenMenu, KIcon(), i18nc( "Make Kruler Height Medium", "&Medium" ),
-             this, SLOT( setMediumLength() ), Qt::CTRL + Qt::Key_M, "length_medium" );
+             this, SLOT( setMediumLength() ), Qt::CTRL + Qt::Key_M, QLatin1String( "length_medium" ) );
   addAction( mLenMenu, KIcon(), i18nc( "Make Kruler Height Tall", "&Tall" ),
-             this, SLOT( setTallLength() ), Qt::CTRL + Qt::Key_T, "length_tall" );
+             this, SLOT( setTallLength() ), Qt::CTRL + Qt::Key_T, QLatin1String( "length_tall" ) );
   addAction( mLenMenu, KIcon(), i18n("&Full Screen Width"),
-             this, SLOT( setFullLength() ), Qt::CTRL + Qt::Key_F, "length_full_length" );
+             this, SLOT( setFullLength() ), Qt::CTRL + Qt::Key_F, QLatin1String( "length_full_length" ) );
   mLenMenu->addSeparator();
   addAction( mLenMenu, KIcon(), i18n( "Length..." ),
-             this, SLOT( slotLength() ), QKeySequence(), "set_length" );
+             this, SLOT( slotLength() ), QKeySequence(), QLatin1String( "set_length" ) );
   mMenu->addMenu( mLenMenu );
 
   KMenu* scaleMenu = new KMenu( i18n( "&Scale" ), this );
   mScaleDirectionAction = addAction( scaleMenu, KIcon(), i18n( "Right to Left" ),
-                                     this, SLOT( switchDirection() ), Qt::Key_D, "right_to_left" );
+                                     this, SLOT( switchDirection() ), Qt::Key_D, QLatin1String( "right_to_left" ) );
   mCenterOriginAction = addAction( scaleMenu, KIcon(), i18n( "Center Origin" ),
-                                   this, SLOT( centerOrigin() ), Qt::Key_C, "center_origin" );
+                                   this, SLOT( centerOrigin() ), Qt::Key_C, QLatin1String( "center_origin" ) );
   mCenterOriginAction->setEnabled( !mRelativeScale );
   mOffsetAction = addAction( scaleMenu, KIcon(), i18n( "Offset..." ),
-                             this, SLOT( slotOffset() ), Qt::Key_O, "set_offset" );
+                             this, SLOT( slotOffset() ), Qt::Key_O, QLatin1String( "set_offset" ) );
   mOffsetAction->setEnabled( !mRelativeScale );
   scaleMenu->addSeparator();
   KAction *relativeScaleAction = addAction( scaleMenu, KIcon(), i18n( "Percentage" ),
-                                            0, 0, QKeySequence(), "toggle_percentage" );
+                                            0, 0, QKeySequence(), QLatin1String( "toggle_percentage" ) );
   relativeScaleAction->setCheckable( true );
   relativeScaleAction->setChecked( mRelativeScale );
   connect( relativeScaleAction, SIGNAL( toggled( bool ) ), this, SLOT( switchRelativeScale( bool ) ) );
@@ -216,15 +217,15 @@ KLineal::KLineal( QWidget *parent )
   mMenu->addMenu( opacityMenu );
 
   KAction *keyBindings = KStandardAction::keyBindings( this, SLOT( slotKeyBindings() ), this );
-  mActionCollection->addAction( "key_bindings", keyBindings );
+  mActionCollection->addAction( QLatin1String(  "key_bindings" ), keyBindings );
   mMenu->addAction( keyBindings );
   KAction *preferences = KStandardAction::preferences( this, SLOT( slotPreferences() ), this );
-  mActionCollection->addAction( "preferences", preferences );
+  mActionCollection->addAction( QLatin1String(  "preferences" ), preferences );
   mMenu->addAction( preferences );
   mMenu->addSeparator();
   KAction *copyColorAction = KStandardAction::copy( this, SLOT( copyColor() ), this );
   copyColorAction->setText( i18n( "Copy Color" ) );
-  mActionCollection->addAction( "copy_color", copyColorAction );
+  mActionCollection->addAction( QLatin1String(  "copy_color" ), copyColorAction );
   mMenu->addAction( copyColorAction );
   mMenu->addSeparator();
   mMenu->addMenu( ( new KHelpMenu( this, KGlobal::mainComponent().aboutData(), true ) )->menu() );
@@ -234,7 +235,7 @@ KLineal::KLineal( QWidget *parent )
   }
 
   KAction *quit = KStandardAction::quit( kapp, SLOT( quit() ), this );
-  mActionCollection->addAction( "quit", quit );
+  mActionCollection->addAction( QLatin1String(  "quit" ), quit );
   mMenu->addAction( quit );
 
   mActionCollection->associateWidget( this );
@@ -256,19 +257,19 @@ void KLineal::createSystemTray()
 {
   if ( !mCloseAction ) {
     mCloseAction = KStandardAction::close( this, SLOT( slotClose() ), this );
-    mActionCollection->addAction( "close", mCloseAction );
+    mActionCollection->addAction( QLatin1String(  "close" ), mCloseAction );
     mMenu->addAction( mCloseAction );
 
     mCloseButton = new QToolButton( this );
     mCloseButton->setIcon( mCloseAction->icon() );
-    mCloseButton->setToolTip( mCloseAction->text().remove( '&' ) );
+    mCloseButton->setToolTip( mCloseAction->text().remove( QLatin1Char(  '&' ) ) );
     connect( mCloseButton, SIGNAL( clicked() ), this, SLOT( slotClose() ) );
   } else {
     mCloseAction->setVisible( true );
   }
-  
+
   if ( !mTrayIcon ) {
-    mTrayIcon = new KRulerSystemTray( "kruler", this, mActionCollection );
+    mTrayIcon = new KRulerSystemTray( QLatin1String( "kruler" ), this, mActionCollection );
     mTrayIcon->setCategory( KStatusNotifierItem::ApplicationStatus );
   }
 }
@@ -624,18 +625,18 @@ void KLineal::slotKeyBindings()
 
 void KLineal::slotPreferences()
 {
-  KConfigDialog *dialog = new KConfigDialog( this, "settings", RulerSettings::self() );
+  KConfigDialog *dialog = new KConfigDialog( this, QLatin1String( "settings" ), RulerSettings::self() );
 
   Ui::ConfigAppearance appearanceConfig;
   QWidget *appearanceConfigWidget = new QWidget( dialog );
   appearanceConfig.setupUi( appearanceConfigWidget );
   appearanceConfig.kcfg_CloseButtonVisible->setEnabled( appearanceConfig.kcfg_TrayIcon->isChecked() );
-  dialog->addPage( appearanceConfigWidget, i18n( "Appearance" ), "preferences-desktop-default-applications" );
+  dialog->addPage( appearanceConfigWidget, i18n( "Appearance" ), QLatin1String( "preferences-desktop-default-applications" ) );
 
   Ui::ConfigAdvanced advancedConfig;
   QWidget *advancedConfigWidget = new QWidget( dialog );
   advancedConfig.setupUi( advancedConfigWidget );
-  dialog->addPage( advancedConfigWidget, i18n( "Advanced" ), "preferences-other" );
+  dialog->addPage( advancedConfigWidget, i18n( "Advanced" ), QLatin1String( "preferences-other" ) );
 
   connect( dialog, SIGNAL( settingsChanged( const QString& ) ), SLOT( loadConfig() ) );
   dialog->exec();
@@ -870,7 +871,7 @@ void KLineal::keyPressEvent( QKeyEvent *e )
   }
 
   move( pos() + dist );
-  KNotification::event( 0, "cursormove", QString() );
+  KNotification::event( QString(), QLatin1String( "cursormove" ), QString() );
 }
 
 /**
