@@ -17,7 +17,7 @@
  *  Boston, MA 02110-1301, USA.
  */
 
-#include <QTimerEvent>
+#include "snapshottimer.h"
 #include <QPainter>
 #include <QPaintEvent>
 #include <QToolTip>
@@ -25,14 +25,12 @@
 #include <KDebug>
 #include <klocale.h>
 
-
-#include "snapshottimer.h"
-
 SnapshotTimer::SnapshotTimer() : QWidget(0)
 {
     setWindowFlags( Qt::WindowStaysOnTopHint | Qt::FramelessWindowHint | Qt::X11BypassWindowManagerHint);
     // The text is copied from paintEvent and the maximum number is used as %1 argument + margins
-    resize( fontMetrics().width( i18n("Snapshot will be taken in %1 seconds", 99) ) + 6 , fontMetrics().height() + 4 );
+    resize( fontMetrics().width( i18np("Snapshot will be taken in 1 second",
+                                       "Snapshot will be taken in %1 seconds", 99) ) + 6 , fontMetrics().height() + 4 );
     connect(&timer, SIGNAL(timeout()), this, SLOT(bell()));
 }
 
