@@ -1,23 +1,28 @@
-/* ============================================================
+/** ===========================================================
+ * @file
  *
- * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * This file is a part of digiKam project
+ * <a href="http://www.digikam.org">http://www.digikam.org</a>
  *
- * Date        : 2006-12-09
- * Description : a tread-safe libraw C++ program interface
+ * @date   2006-12-09
+ * @brief  a tread-safe libraw C++ program interface
  *
- * Copyright (C) 2006-2010 by Gilles Caulier <caulier dot gilles at gmail dot com> 
- * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2007-2008 by Guillaume Castagnino <casta at xwing dot info>
+ * @author Copyright (C) 2006-2010 by Gilles Caulier
+ *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
+ * @author Copyright (C) 2006-2010 by Marcel Wiesweg
+ *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
+ * @author Copyright (C) 2007-2008 by Guillaume Castagnino
+ *         <a href="mailto:casta at xwing dot info">casta at xwing dot info</a>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
  * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option) any later version.
+ * either version 2, or (at your option)
+ * any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * ============================================================ */
@@ -38,7 +43,6 @@
 
 #include "version.h"
 #include "rawfiles.h"
-#include "libraw_config.h"
 #include "kdcraw_p.h"
 
 namespace KDcrawIface
@@ -82,16 +86,16 @@ bool KDcraw::loadEmbeddedPreview(QImage& image, const QString& path)
 
     if ( loadEmbeddedPreview(imgData, path) )
     {
-        kDebug(51002) << "Preview data size:" << imgData.size();
+        kDebug() << "Preview data size:" << imgData.size();
 
         if (image.loadFromData( imgData ))
         {
-            kDebug(51002) << "Using embedded RAW preview extraction";
+            kDebug() << "Using embedded RAW preview extraction";
             return true;
         }
     }
 
-    kDebug(51002) << "Failed to load embedded RAW preview";
+    kDebug() << "Failed to load embedded RAW preview";
     return false;
 }
 
@@ -109,7 +113,7 @@ bool KDcraw::loadEmbeddedPreview(QByteArray& imgData, const QString& path)
     int ret = raw.open_file(QFile::encodeName(path));
     if (ret != LIBRAW_SUCCESS)
     {
-        kDebug(51002) << "LibRaw: failed to run open_file: " << libraw_strerror(ret) << endl;
+        kDebug() << "LibRaw: failed to run open_file: " << libraw_strerror(ret);
         raw.recycle();
         return false;
     }
@@ -118,15 +122,15 @@ bool KDcraw::loadEmbeddedPreview(QByteArray& imgData, const QString& path)
     if (ret != LIBRAW_SUCCESS)
     {
         raw.recycle();
-        kDebug(51002) << "LibRaw: failed to run unpack_thumb: " << libraw_strerror(ret) << endl;
+        kDebug() << "LibRaw: failed to run unpack_thumb: " << libraw_strerror(ret);
         raw.recycle();
         return false;
     }
 
-    libraw_processed_image_t *thumb = raw.dcraw_make_mem_thumb(&ret);
+    libraw_processed_image_t* thumb = raw.dcraw_make_mem_thumb(&ret);
     if(!thumb)
     {
-        kDebug(51002) << "LibRaw: failed to run dcraw_make_mem_thumb: " << libraw_strerror(ret) << endl;
+        kDebug() << "LibRaw: failed to run dcraw_make_mem_thumb: " << libraw_strerror(ret);
         raw.recycle();
         return false;
     }
@@ -136,12 +140,13 @@ bool KDcraw::loadEmbeddedPreview(QByteArray& imgData, const QString& path)
     else
         imgData = QByteArray((const char*)thumb->data, (int)thumb->data_size);
 
-    free(thumb);
+    // Clear memory allocation. Introduced with LibRaw 0.11.0
+    raw.dcraw_clear_mem(thumb);
     raw.recycle();
 
     if ( imgData.isEmpty() )
     {
-        kDebug(51002) << "Failed to load JPEG thumb from LibRaw!" << endl;
+        kDebug() << "Failed to load JPEG thumb from LibRaw!";
         return false;
     }
 
@@ -157,12 +162,12 @@ bool KDcraw::loadHalfPreview(QImage& image, const QString& path)
     if (!fileInfo.exists() || ext.isEmpty() || !rawFilesExt.toUpper().contains(ext))
         return false;
 
-    kDebug(51002) << "Try to use reduced RAW picture extraction" << endl;
+    kDebug() << "Try to use reduced RAW picture extraction";
 
     LibRaw raw;
-    raw.imgdata.params.use_auto_wb    = 1;         // Use automatic white balance.
-    raw.imgdata.params.use_camera_wb  = 1;         // Use camera white balance, if possible.
-    raw.imgdata.params.half_size      = 1;         // Half-size color image (3x faster than -q).
+    raw.imgdata.params.use_auto_wb   = 1;         // Use automatic white balance.
+    raw.imgdata.params.use_camera_wb = 1;         // Use camera white balance, if possible.
+    raw.imgdata.params.half_size     = 1;         // Half-size color image (3x faster than -q).
 
     // NOTE: new magic option introduced by LibRaw 0.7.0 to to make better noise filtration.
     raw.imgdata.params.filtering_mode = LIBRAW_FILTERING_AUTOMATIC;
@@ -170,7 +175,7 @@ bool KDcraw::loadHalfPreview(QImage& image, const QString& path)
     int ret = raw.open_file(QFile::encodeName(path));
     if (ret != LIBRAW_SUCCESS)
     {
-        kDebug(51002) << "LibRaw: failed to run open_file: " << libraw_strerror(ret) << endl;
+        kDebug() << "LibRaw: failed to run open_file: " << libraw_strerror(ret);
         raw.recycle();
         return false;
     }
@@ -178,7 +183,7 @@ bool KDcraw::loadHalfPreview(QImage& image, const QString& path)
     ret = raw.unpack();
     if (ret != LIBRAW_SUCCESS)
     {
-        kDebug(51002) << "LibRaw: failed to run unpack: " << libraw_strerror(ret) << endl;
+        kDebug() << "LibRaw: failed to run unpack: " << libraw_strerror(ret);
         raw.recycle();
         return false;
     }
@@ -186,7 +191,7 @@ bool KDcraw::loadHalfPreview(QImage& image, const QString& path)
     ret = raw.dcraw_process();
     if (ret != LIBRAW_SUCCESS)
     {
-        kDebug(51002) << "LibRaw: failed to run dcraw_process: " << libraw_strerror(ret) << endl;
+        kDebug() << "LibRaw: failed to run dcraw_process: " << libraw_strerror(ret);
         raw.recycle();
         return false;
     }
@@ -194,23 +199,25 @@ bool KDcraw::loadHalfPreview(QImage& image, const QString& path)
     libraw_processed_image_t* halfImg = raw.dcraw_make_mem_image(&ret);
     if(!halfImg)
     {
-        kDebug(51002) << "LibRaw: failed to run dcraw_make_mem_image: " << libraw_strerror(ret) << endl;
+        kDebug() << "LibRaw: failed to run dcraw_make_mem_image: " << libraw_strerror(ret);
         raw.recycle();
         return false;
     }
 
     QByteArray imgData;
     KDcrawPriv::createPPMHeader(imgData, halfImg);
-    free(halfImg);
+    // Clear memory allocation. Introduced with LibRaw 0.11.0
+    raw.dcraw_clear_mem(halfImg);
     raw.recycle();
 
     if (!image.loadFromData(imgData))
     {
-        kDebug(51002) << "Failed to load PPM data from LibRaw!" << endl;
+        kDebug() << "Failed to load PPM data from LibRaw!";
         return false;
     }
 
-    kDebug(51002) << "Using reduced RAW picture extraction" << endl;
+    kDebug() << "Using reduced RAW picture extraction";
+
     return true;
 }
 
@@ -229,7 +236,7 @@ bool KDcraw::rawFileIdentify(DcrawInfoContainer& identify, const QString& path)
     int ret = raw.open_file(QFile::encodeName(path));
     if (ret != LIBRAW_SUCCESS)
     {
-        kDebug(51002) << "LibRaw: failed to run open_file: " << libraw_strerror(ret) << endl;
+        kDebug() << "LibRaw: failed to run open_file: " << libraw_strerror(ret);
         raw.recycle();
         return false;
     }
@@ -237,7 +244,7 @@ bool KDcraw::rawFileIdentify(DcrawInfoContainer& identify, const QString& path)
     ret = raw.adjust_sizes_info_only();
     if (ret != LIBRAW_SUCCESS)
     {
-        kDebug(51002) << "LibRaw: failed to run adjust_sizes_info_only: " << libraw_strerror(ret) << endl;
+        kDebug() << "LibRaw: failed to run adjust_sizes_info_only: " << libraw_strerror(ret);
         raw.recycle();
         return false;
     }
@@ -279,7 +286,7 @@ bool KDcraw::extractRAWData(const QString& filePath, QByteArray& rawData, DcrawI
     int ret = raw.open_file(QFile::encodeName(filePath));
     if (ret != LIBRAW_SUCCESS)
     {
-        kDebug(51002) << "LibRaw: failed to run open_file: " << libraw_strerror(ret) << endl;
+        kDebug() << "LibRaw: failed to run open_file: " << libraw_strerror(ret);
         raw.recycle();
         return false;
     }
@@ -298,7 +305,7 @@ bool KDcraw::extractRAWData(const QString& filePath, QByteArray& rawData, DcrawI
     ret = raw.unpack();
     if (ret != LIBRAW_SUCCESS)
     {
-        kDebug(51002) << "LibRaw: failed to run unpack: " << libraw_strerror(ret) << endl;
+        kDebug() << "LibRaw: failed to run unpack: " << libraw_strerror(ret);
         raw.recycle();
         return false;
     }
@@ -309,7 +316,7 @@ bool KDcraw::extractRAWData(const QString& filePath, QByteArray& rawData, DcrawI
         ret = raw.add_masked_borders_to_bitmap();
         if (ret != LIBRAW_SUCCESS)
         {
-            kDebug(51002) << "LibRaw: failed to add masked borders: " << libraw_strerror(ret) << endl;
+            kDebug() << "LibRaw: failed to add masked borders: " << libraw_strerror(ret);
             raw.recycle();
             return false;
         }
@@ -334,7 +341,7 @@ bool KDcraw::extractRAWData(const QString& filePath, QByteArray& rawData, DcrawI
     rawData = QByteArray();
     rawData.resize((int)(raw.imgdata.sizes.iwidth * raw.imgdata.sizes.iheight * sizeof(unsigned short)));
 
-    unsigned short *output = (unsigned short *)rawData.data();
+    unsigned short* output = (unsigned short*)rawData.data();
 
     for (uint row=0 ; row < raw.imgdata.sizes.iheight ; row++)
     {
@@ -351,15 +358,15 @@ bool KDcraw::extractRAWData(const QString& filePath, QByteArray& rawData, DcrawI
     return true;
 }
 
-bool KDcraw::decodeHalfRAWImage(const QString& filePath, const RawDecodingSettings& rawDecodingSettings, 
-                                QByteArray &imageData, int &width, int &height, int &rgbmax)
+bool KDcraw::decodeHalfRAWImage(const QString& filePath, const RawDecodingSettings& rawDecodingSettings,
+                                QByteArray& imageData, int& width, int& height, int& rgbmax)
 {
     m_rawDecodingSettings                    = rawDecodingSettings;
     m_rawDecodingSettings.halfSizeColorImage = true;
     return (loadFromLibraw(filePath, imageData, width, height, rgbmax));
 }
 
-bool KDcraw::decodeRAWImage(const QString& filePath, const RawDecodingSettings& rawDecodingSettings, 
+bool KDcraw::decodeRAWImage(const QString& filePath, const RawDecodingSettings& rawDecodingSettings,
                             QByteArray& imageData, int& width, int& height, int& rgbmax)
 {
     m_rawDecodingSettings = rawDecodingSettings;
@@ -553,7 +560,7 @@ bool KDcraw::loadFromLibraw(const QString& filePath, QByteArray& imageData,
                 RGB[0] = 1.0 / RGB[0];
                 RGB[1] = 1.0 / RGB[1];
                 RGB[2] = 1.0 / RGB[2];
-                kDebug(51002) << "Warning: cannot get daylight multipliers" << endl;
+                kDebug() << "Warning: cannot get daylight multipliers";
             }
 
             // (-r) set Raw Color Balance Multipliers.
@@ -649,13 +656,13 @@ bool KDcraw::loadFromLibraw(const QString& filePath, QByteArray& imageData,
     d->setProgress(0.1);
 
     args.append(filePath);
-    kDebug(51002) << "LibRaw: dcraw emulation: " << args << endl;
-    kDebug(51002) << "LibRaw highlights adjustements : " << m_rawDecodingSettings.fixColorsHighlights << endl;
+    kDebug() << "LibRaw: dcraw emulation: " << args;
+    kDebug() << "LibRaw highlights adjustements : " << m_rawDecodingSettings.fixColorsHighlights;
 
     int ret = raw.open_file(QFile::encodeName(filePath));
     if (ret != LIBRAW_SUCCESS)
     {
-        kDebug(51002) << "LibRaw: failed to run open_file: " << libraw_strerror(ret) << endl;
+        kDebug() << "LibRaw: failed to run open_file: " << libraw_strerror(ret);
         raw.recycle();
         return false;
     }
@@ -670,7 +677,7 @@ bool KDcraw::loadFromLibraw(const QString& filePath, QByteArray& imageData,
     ret = raw.unpack();
     if (ret != LIBRAW_SUCCESS)
     {
-        kDebug(51002) << "LibRaw: failed to run unpack: " << libraw_strerror(ret) << endl;
+        kDebug() << "LibRaw: failed to run unpack: " << libraw_strerror(ret);
         raw.recycle();
         return false;
     }
@@ -684,21 +691,21 @@ bool KDcraw::loadFromLibraw(const QString& filePath, QByteArray& imageData,
 
     if (m_rawDecodingSettings.fixColorsHighlights)
     {
-        kDebug(51002) << "Applying LibRaw highlights adjustements" << endl;
+        kDebug() << "Applying LibRaw highlights adjustements";
         // 1.0 is fallback to default value
-        raw.imgdata.params.adjust_maximum_thr = 1.0; 
+        raw.imgdata.params.adjust_maximum_thr = 1.0;
     }
     else
     {
-        kDebug(51002) << "Disabling LibRaw highlights adjustements" << endl;
+        kDebug() << "Disabling LibRaw highlights adjustements";
         // 0.0 disables this feature
-        raw.imgdata.params.adjust_maximum_thr = 0.0; 
+        raw.imgdata.params.adjust_maximum_thr = 0.0;
     }
 
     ret = raw.dcraw_process();
     if (ret != LIBRAW_SUCCESS)
     {
-        kDebug(51002) << "LibRaw: failed to run dcraw_process: " << libraw_strerror(ret) << endl;
+        kDebug() << "LibRaw: failed to run dcraw_process: " << libraw_strerror(ret);
         raw.recycle();
         return false;
     }
@@ -713,14 +720,15 @@ bool KDcraw::loadFromLibraw(const QString& filePath, QByteArray& imageData,
     libraw_processed_image_t* img = raw.dcraw_make_mem_image(&ret);
     if(!img)
     {
-        kDebug(51002) << "LibRaw: failed to run dcraw_make_mem_image: " << libraw_strerror(ret) << endl;
+        kDebug() << "LibRaw: failed to run dcraw_make_mem_image: " << libraw_strerror(ret);
         raw.recycle();
         return false;
     }
 
     if (m_cancel)
     {
-        free(img);
+        // Clear memory allocation. Introduced with LibRaw 0.11.0
+        raw.dcraw_clear_mem(img);
         raw.recycle();
         return false;
     }
@@ -730,16 +738,19 @@ bool KDcraw::loadFromLibraw(const QString& filePath, QByteArray& imageData,
     height    = img->height;
     rgbmax    = (1 << img->bits)-1;
     imageData = QByteArray((const char*)img->data, (int)img->data_size);
-    free(img);
+    // Clear memory allocation. Introduced with LibRaw 0.11.0
+    raw.dcraw_clear_mem(img);
     raw.recycle();
 
     if (m_cancel)
+    {
         return false;
+    }
     d->setProgress(0.4);
 
-    kDebug(51002) << "LibRaw: data info: width=" << width 
-                  << " height=" << height 
-                  << " rgbmax=" << rgbmax << endl;
+    kDebug() << "LibRaw: data info: width=" << width
+             << " height=" << height
+             << " rgbmax=" << rgbmax;
 
     return true;
 }
@@ -777,7 +788,7 @@ QString KDcraw::librawVersion()
 
 bool KDcraw::librawUseGomp()
 {
-#ifdef USE_OPENMP
+#ifdef LIBRAW_USE_OPENMP
     return true;
 #else
     return false;
