@@ -1,13 +1,18 @@
-/* ============================================================
+/** ===========================================================
+ * @file
  *
- * This file is a part of kipi-plugins project
- * http://www.kipi-plugins.org
+ * This file is a part of digiKam project
+ * <a href="http://www.digikam.org">http://www.digikam.org</a>
  *
- * Date        : 2008-03-14
- * Description : A widget to host settings as expander box
+ * @date   2008-03-14
+ * @brief  A widget to host settings as expander box
  *
- * Copyright (C) 2008-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * @author Copyright (C) 2008-2010 by Gilles Caulier
+ *         <a href="mailto:caulier dot gilles at gmail dot com">caulier dot gilles at gmail dot com</a>
+ * @author Copyright (C) 2008-2010 by Marcel Wiesweg
+ *         <a href="mailto:marcel dot wiesweg at gmx dot de">marcel dot wiesweg at gmx dot de</a>
+ * @author Copyright (C) 2010 by Manuel Viet
+ *         <a href="mailto:contact at 13zenrv dot fr">contact at 13zenrv dot fr</a>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -17,7 +22,7 @@
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU General Public License for more details.
  *
  * ============================================================ */
@@ -34,6 +39,7 @@
 #include <QStyleOption>
 #include <QGridLayout>
 #include <QHBoxLayout>
+#include <QCheckBox>
 
 // KDE includes
 
@@ -47,13 +53,13 @@
 namespace KDcrawIface
 {
 
-RClickLabel::RClickLabel(QWidget *parent)
+RClickLabel::RClickLabel(QWidget* parent)
            : QLabel(parent)
 {
     setCursor(Qt::PointingHandCursor);
 }
 
-RClickLabel::RClickLabel(const QString& text, QWidget *parent)
+RClickLabel::RClickLabel(const QString& text, QWidget* parent)
            : QLabel(text, parent)
 {
     setCursor(Qt::PointingHandCursor);
@@ -71,7 +77,7 @@ void RClickLabel::mouseReleaseEvent(QMouseEvent* event)
     }
 }
 
-void RClickLabel::keyPressEvent(QKeyEvent *e)
+void RClickLabel::keyPressEvent(QKeyEvent* e)
 {
     switch (e->key())
     {
@@ -89,13 +95,13 @@ void RClickLabel::keyPressEvent(QKeyEvent *e)
 
 // ------------------------------------------------------------------------
 
-RSqueezedClickLabel::RSqueezedClickLabel(QWidget *parent)
+RSqueezedClickLabel::RSqueezedClickLabel(QWidget* parent)
                    : KSqueezedTextLabel(parent)
 {
     setCursor(Qt::PointingHandCursor);
 }
 
-RSqueezedClickLabel::RSqueezedClickLabel(const QString& text, QWidget *parent)
+RSqueezedClickLabel::RSqueezedClickLabel(const QString& text, QWidget* parent)
                    : KSqueezedTextLabel(text, parent)
 {
     setCursor(Qt::PointingHandCursor);
@@ -113,7 +119,7 @@ void RSqueezedClickLabel::mouseReleaseEvent(QMouseEvent* event)
     }
 }
 
-void RSqueezedClickLabel::keyPressEvent(QKeyEvent *e)
+void RSqueezedClickLabel::keyPressEvent(QKeyEvent* e)
 {
     switch (e->key())
     {
@@ -131,7 +137,7 @@ void RSqueezedClickLabel::keyPressEvent(QKeyEvent *e)
 
 // ------------------------------------------------------------------------
 
-RArrowClickLabel::RArrowClickLabel(QWidget *parent)
+RArrowClickLabel::RArrowClickLabel(QWidget* parent)
                 : QWidget(parent), m_arrowType(Qt::DownArrow)
 {
     setCursor(Qt::PointingHandCursor);
@@ -245,7 +251,7 @@ QSize RArrowClickLabel::sizeHint() const
 
 // ------------------------------------------------------------------------
 
-class RLabelExpanderPriv
+class RLabelExpander::RLabelExpanderPriv
 {
 
 public:
@@ -259,34 +265,38 @@ public:
         arrow           = 0;
         line            = 0;
         hbox            = 0;
+        checkBox        = 0;
         expandByDefault = true;
     }
 
     bool              expandByDefault;
 
-    QLabel           *pixmapLabel;
-    QWidget          *containerWidget;
-    QGridLayout      *grid;
+    QCheckBox*        checkBox;
+    QLabel*           pixmapLabel;
+    QWidget*          containerWidget;
+    QGridLayout*      grid;
 
-    KSeparator       *line;
-    QWidget          *hbox;
+    KSeparator*       line;
+    QWidget*          hbox;
 
-    RArrowClickLabel *arrow;
-    RClickLabel      *clickLabel;
+    RArrowClickLabel* arrow;
+    RClickLabel*      clickLabel;
 };
 
-RLabelExpander::RLabelExpander(QWidget *parent)
+RLabelExpander::RLabelExpander(QWidget* parent)
               : QWidget(parent), d(new RLabelExpanderPriv)
 {
     d->grid        = new QGridLayout(this);
     d->line        = new KSeparator(Qt::Horizontal, this);
     d->hbox        = new QWidget(this);
     d->arrow       = new RArrowClickLabel(d->hbox);
+    d->checkBox    = new QCheckBox(d->hbox);
     d->pixmapLabel = new QLabel(d->hbox);
     d->clickLabel  = new RClickLabel(d->hbox);
 
-    QHBoxLayout *hlay = new QHBoxLayout(d->hbox);
+    QHBoxLayout* hlay = new QHBoxLayout(d->hbox);
     hlay->addWidget(d->arrow);
+    hlay->addWidget(d->checkBox);
     hlay->addWidget(d->pixmapLabel);
     hlay->addWidget(d->clickLabel, 10);
     hlay->setMargin(0);
@@ -296,6 +306,7 @@ RLabelExpander::RLabelExpander(QWidget *parent)
     d->pixmapLabel->setCursor(Qt::PointingHandCursor);
 
     d->hbox->setCursor(Qt::PointingHandCursor);
+    setCheckBoxVisible(false);
 
     d->grid->addWidget(d->line, 0, 0, 1, 3);
     d->grid->addWidget(d->hbox, 1, 0, 1, 3);
@@ -308,6 +319,9 @@ RLabelExpander::RLabelExpander(QWidget *parent)
 
     connect(d->clickLabel, SIGNAL(activated()),
             this, SLOT(slotToggleContainer()));
+
+    connect(d->checkBox, SIGNAL(toggled(bool)),
+            this, SIGNAL(signalToggled(bool)));
 }
 
 RLabelExpander::~RLabelExpander()
@@ -315,6 +329,26 @@ RLabelExpander::~RLabelExpander()
     delete d;
 }
 
+void RLabelExpander::setCheckBoxVisible(bool b)
+{
+    d->checkBox->setVisible(b);
+}
+
+bool RLabelExpander::checkBoxIsVisible() const
+{
+    return d->checkBox->isVisible();
+}
+
+void RLabelExpander::setChecked(bool b)
+{
+    d->checkBox->setChecked(b);
+}
+
+bool RLabelExpander::isChecked() const
+{
+    return d->checkBox->isChecked();
+}
+
 void RLabelExpander::setLineVisible(bool b)
 {
     d->line->setVisible(b);
@@ -395,7 +429,7 @@ void RLabelExpander::slotToggleContainer()
         setExpanded(!d->containerWidget->isVisible());
 }
 
-bool RLabelExpander::eventFilter(QObject *obj, QEvent *ev)
+bool RLabelExpander::eventFilter(QObject* obj, QEvent* ev)
 {
     if ( obj == d->pixmapLabel)
     {
@@ -418,7 +452,7 @@ bool RLabelExpander::eventFilter(QObject *obj, QEvent *ev)
 
 // ------------------------------------------------------------------------
 
-class RExpanderBoxPriv
+class RExpanderBox::RExpanderBoxPriv
 {
 
 public:
@@ -429,10 +463,10 @@ public:
         vbox   = 0;
     }
 
-    void createItem(int index, QWidget *w, const QPixmap& pix, const QString& txt,
+    void createItem(int index, QWidget* w, const QPixmap& pix, const QString& txt,
                     const QString& objName, bool expandBydefault)
     {
-        RLabelExpander *exp = new RLabelExpander(parent->viewport());
+        RLabelExpander* exp = new RLabelExpander(parent->viewport());
         exp->setText(txt);
         exp->setIcon(pix);
         exp->setWidget(w);
@@ -453,21 +487,24 @@ public:
 
         parent->connect(exp, SIGNAL(signalExpanded(bool)),
                         parent, SLOT(slotItemExpanded(bool)));
+
+        parent->connect(exp, SIGNAL(signalToggled(bool)),
+                        parent, SLOT(slotItemToggled(bool)));
     }
 
-    QList<RLabelExpander*>  wList;
+    QList<RLabelExpander*> wList;
 
-    QVBoxLayout            *vbox;
+    QVBoxLayout*           vbox;
 
-    RExpanderBox           *parent;
+    RExpanderBox*          parent;
 };
 
-RExpanderBox::RExpanderBox(QWidget *parent)
+RExpanderBox::RExpanderBox(QWidget* parent)
             : QScrollArea(parent), d(new RExpanderBoxPriv(this))
 {
     setFrameStyle(QFrame::NoFrame);
     setWidgetResizable(true);
-    QWidget *main = new QWidget(viewport());
+    QWidget* main = new QWidget(viewport());
     d->vbox       = new QVBoxLayout(main);
     d->vbox->setMargin(0);
     d->vbox->setSpacing(KDialog::spacingHint());
@@ -485,13 +522,37 @@ RExpanderBox::~RExpanderBox()
     delete d;
 }
 
-void RExpanderBox::addItem(QWidget *w, const QPixmap& pix, const QString& txt,
+void RExpanderBox::setCheckBoxVisible(int index, bool b)
+{
+    if (index > d->wList.count() || index < 0) return;
+    d->wList[index]->setCheckBoxVisible(b);
+}
+
+bool RExpanderBox::checkBoxIsVisible(int index) const
+{
+    if (index > d->wList.count() || index < 0) return false;
+    return d->wList[index]->checkBoxIsVisible();
+}
+
+void RExpanderBox::setChecked(int index, bool b)
+{
+    if (index > d->wList.count() || index < 0) return;
+    d->wList[index]->setChecked(b);
+}
+
+bool RExpanderBox::isChecked(int index) const
+{
+    if (index > d->wList.count() || index < 0) return false;
+    return d->wList[index]->isChecked();
+}
+
+void RExpanderBox::addItem(QWidget* w, const QPixmap& pix, const QString& txt,
                            const QString& objName, bool expandBydefault)
 {
     d->createItem(-1, w, pix, txt, objName, expandBydefault);
 }
 
-void RExpanderBox::addItem(QWidget *w, const QString& txt,
+void RExpanderBox::addItem(QWidget* w, const QString& txt,
                            const QString& objName, bool expandBydefault)
 {
     addItem(w, QPixmap(), txt, objName, expandBydefault);
@@ -502,7 +563,7 @@ void RExpanderBox::addStretch()
     d->vbox->addStretch(10);
 }
 
-void RExpanderBox::insertItem(int index, QWidget *w, const QPixmap& pix, const QString& txt,
+void RExpanderBox::insertItem(int index, QWidget* w, const QPixmap& pix, const QString& txt,
                               const QString& objName, bool expandBydefault)
 {
     d->createItem(index, w, pix, txt, objName, expandBydefault);
@@ -518,7 +579,17 @@ void RExpanderBox::slotItemExpanded(bool b)
     }
 }
 
-void RExpanderBox::insertItem(int index, QWidget *w, const QString& txt,
+void RExpanderBox::slotItemToggled(bool b)
+{
+    RLabelExpander* exp = dynamic_cast<RLabelExpander*>(sender());
+    if (exp)
+    {
+        int index = indexOf(exp);
+        emit signalItemToggled(index, b);
+    }
+}
+
+void RExpanderBox::insertItem(int index, QWidget* w, const QString& txt,
                               const QString& objName, bool expandBydefault)
 {
     insertItem(index, w, QPixmap(), txt, objName, expandBydefault);
@@ -596,7 +667,7 @@ RLabelExpander* RExpanderBox::widget(int index) const
     return d->wList[index];
 }
 
-int RExpanderBox::indexOf(RLabelExpander *widget) const
+int RExpanderBox::indexOf(RLabelExpander* widget) const
 {
     for (int i = 0 ; i < count(); ++i)
     {
@@ -660,4 +731,47 @@ void RExpanderBox::writeSettings()
     config->sync();
 }
 
+// ------------------------------------------------------------------------
+
+RExpanderBoxExclusive::RExpanderBoxExclusive(QWidget* parent)
+                     : RExpanderBox(parent)
+{
+    setIsToolBox(true);
+}
+
+RExpanderBoxExclusive::~RExpanderBoxExclusive()
+{
+}
+
+void RExpanderBoxExclusive::slotItemExpanded(bool b)
+{
+    RLabelExpander* exp = dynamic_cast<RLabelExpander*>(sender());
+    if (!exp) return;
+
+    if (isToolBox() && b)
+    {
+        int item = 0;
+
+        while (item < count())
+        {
+            if (isItemExpanded(item) && item != indexOf(exp))
+            {
+                setItemExpanded(item, false);
+            }
+            item++;
+        }
+    }
+    emit signalItemExpanded(indexOf(exp), b);
+}
+
+void RExpanderBoxExclusive::setIsToolBox(bool b)
+{
+    m_toolbox = b;
+}
+
+bool RExpanderBoxExclusive::isToolBox() const
+{
+    return (m_toolbox);
+}
+
 } // namespace KDcrawIface
