@@ -24,11 +24,11 @@
 #include <dom/dom_node.h>
 #include <dom/dom_html.h>
 
-#include <okular/core/action.h>
-#include <okular/core/observer.h> //for PAGEVIEW_ID
-#include <okular/core/page.h>
-#include <okular/core/textpage.h>
-#include <okular/core/utils.h>
+#include <core/action.h>
+#include <core/observer.h> //for PAGEVIEW_ID
+#include <core/page.h>
+#include <core/textpage.h>
+#include <core/utils.h>
 
 static KAboutData createAboutData()
 {
