@@ -15,9 +15,9 @@
 #include <kaboutdata.h>
 #include <klocale.h>
 
-#include <okular/core/document.h>
-#include <okular/core/page.h>
-#include <okular/core/fileprinter.h>
+#include <core/document.h>
+#include <core/page.h>
+#include <core/fileprinter.h>
 
 static KAboutData createAboutData()
 {
@@ -25,7 +25,7 @@ static KAboutData createAboutData()
          "okular_comicbook",
          "okular_comicbook",
          ki18n( "ComicBook Backend" ),
-         "0.2",
+         "0.2.1",
          ki18n( "A renderer for various comic book formats" ),
          KAboutData::License_GPL,
          ki18n( "© 2007-2008 Tobias Koenig" )
