@@ -32,10 +32,10 @@
 #include <QImageReader>
 #include <QMutex>
 
-#include <okular/core/document.h>
-#include <okular/core/page.h>
-#include <okular/core/area.h>
-#include <okular/core/fileprinter.h>
+#include <core/document.h>
+#include <core/page.h>
+#include <core/area.h>
+#include <core/fileprinter.h>
 
 const int XpsDebug = 4712;
 
@@ -45,7 +45,7 @@ static KAboutData createAboutData()
          "okular_xps",
          "okular_xps",
          ki18n( "XPS Backend" ),
-         "0.3.1",
+         "0.3.2",
          ki18n( "An XPS backend" ),
          KAboutData::License_GPL,
          ki18n( "© 2006-2007 Brad Hards\n"
@@ -345,7 +345,7 @@ static QPainterPath parseAbbreviatedPathData( const QString &data)
                 {
                     QPointF point1 = getPointFromString(&token, isRelative, currPos);
                     QPointF point2 = getPointFromString(&token, isRelative, currPos);
-                    path.quadTo(point2, point2);
+                    path.quadTo(point1, point2);
                 }
                 break;
             case 's': // Smooth cubic bezier curve
@@ -1476,11 +1476,19 @@ QFont XpsFile::getFontByName( const QString &fileName, float size )
         return QFont();
     }
 
-    QString fontFamily = m_fontDatabase.applicationFontFamilies( index ).at(0);
-    QString fontStyle =  m_fontDatabase.styles( fontFamily ).at(0);
-    QFont font = m_fontDatabase.font(fontFamily, fontStyle, qRound(size) );
-
-    return font;
+    const QStringList fontFamilies = m_fontDatabase.applicationFontFamilies( index );
+    if ( fontFamilies.isEmpty() ) {
+      kWarning(XpsDebug) << "The unexpected has happened. No font family for a known font:" << fileName << index;
+      return QFont();
+    }
+    const QString fontFamily = fontFamilies[0];
+    const QStringList fontStyles = m_fontDatabase.styles( fontFamily );
+    if ( fontStyles.isEmpty() ) {
+      kWarning(XpsDebug) << "The unexpected has happened. No font style for a known font family:" << fileName << index << fontFamily ;
+      return QFont();
+    }
+    const QString fontStyle =  fontStyles[0];
+    return m_fontDatabase.font(fontFamily, fontStyle, qRound(size));
 }
 
 int XpsFile::loadFontByName( const QString &fileName )
@@ -1972,7 +1980,7 @@ const Okular::DocumentInfo * XpsFile::generateDocumentInfo()
 
     m_docInfo = new Okular::DocumentInfo();
 
-    m_docInfo->set( Okular::DocumentInfo::MimeType, "application/vnd.ms-xpsdocument" );
+    m_docInfo->set( Okular::DocumentInfo::MimeType, "application/oxps" );
 
     if ( ! m_corePropertiesFileName.isEmpty() ) {
         const KZipFileEntry* corepropsFile = static_cast<const KZipFileEntry *>(m_xpsArchive->directory()->entry(m_corePropertiesFileName));
