@@ -107,10 +107,10 @@ void PixmapPreviewSelector::iconComboChanged( const QString& icon )
         m_icon = icon;
     }
 
-    QString path;
-    QPixmap pixmap = GuiUtils::iconLoader()->loadIcon( m_icon.toLower(), KIconLoader::User, m_previewSize, KIconLoader::DefaultState, QStringList(), &path, true );
-    if ( path.isEmpty() )
-        pixmap = GuiUtils::iconLoader()->loadIcon( m_icon.toLower(), KIconLoader::NoGroup, m_previewSize );
+    QPixmap pixmap = GuiUtils::loadStamp( m_icon, QSize(), m_previewSize );
+    const QRect cr = m_iconLabel->contentsRect();
+    if ( pixmap.width() > cr.width() || pixmap.height() > cr.height() )
+        pixmap = pixmap.scaled( cr.size(), Qt::KeepAspectRatio, Qt::SmoothTransformation );
     m_iconLabel->setPixmap( pixmap );
 
     emit iconChanged( m_icon );
@@ -265,12 +265,10 @@ QWidget * StampAnnotationWidget::createStyleWidget()
     gblay->addWidget( m_pixmapSelector );
     m_pixmapSelector->setEditable( true );
 
-    // FIXME!!! use the standard names instead (when we'll have the artwork)
     m_pixmapSelector->addItem( i18n( "Okular" ), "okular" );
     m_pixmapSelector->addItem( i18n( "Bookmark" ), "bookmarks" );
     m_pixmapSelector->addItem( i18n( "KDE" ), "kde" );
     m_pixmapSelector->addItem( i18n( "Information" ), "help-about" );
-#if 0
     m_pixmapSelector->addItem( i18n( "Approved" ), "Approved" );
     m_pixmapSelector->addItem( i18n( "As Is" ), "AsIs" );
     m_pixmapSelector->addItem( i18n( "Confidential" ), "Confidential" );
@@ -285,7 +283,6 @@ QWidget * StampAnnotationWidget::createStyleWidget()
     m_pixmapSelector->addItem( i18n( "Not For Public Release" ), "NotForPublicRelease" );
     m_pixmapSelector->addItem( i18n( "Sold" ), "Sold" );
     m_pixmapSelector->addItem( i18n( "Top Secret" ), "TopSecret" );
-#endif
     m_pixmapSelector->setIcon( m_stampAnn->stampIconName() );
     m_pixmapSelector->setPreviewSize( 64 );
 
