@@ -599,15 +599,18 @@ void PagePainter::paintCroppedPageOnPainter( QPainter * destPainter, const Okula
 
                 // get pixmap and alpha blend it if needed
                 QPixmap pixmap = GuiUtils::loadStamp( stamp->stampIconName(), annotBoundary.size() );
-                QImage scaledImage;
-                scalePixmapOnImage( scaledImage, &pixmap, annotBoundary.width(),
-                                    annotBoundary.height(), innerRect, QImage::Format_ARGB32 );
-                if ( opacity < 255 )
-                    changeImageAlpha( scaledImage, opacity );
-                pixmap = QPixmap::fromImage( scaledImage );
+                if ( !pixmap.isNull() ) // should never happen but can happen on huge sizes
+                {
+                    QImage scaledImage;
+                    scalePixmapOnImage( scaledImage, &pixmap, annotBoundary.width(),
+                                        annotBoundary.height(), innerRect, QImage::Format_ARGB32 );
+                    if ( opacity < 255 )
+                        changeImageAlpha( scaledImage, opacity );
+                    pixmap = QPixmap::fromImage( scaledImage );
 
-                // draw the scaled and al
-                mixedPainter->drawPixmap( annotRect.topLeft(), pixmap );
+                    // draw the scaled and al
+                    mixedPainter->drawPixmap( annotRect.topLeft(), pixmap );
+                }
             }
             // draw GeomAnnotation
             else if ( type == Okular::Annotation::AGeom )
@@ -735,7 +738,7 @@ void PagePainter::scalePixmapOnImage ( QImage & dest, const QPixmap * src,
     unsigned int * destData = (unsigned int *)dest.bits();
 
     // source image (1:1 conversion from pixmap)
-    QImage srcImage = src->toImage();
+    QImage srcImage = src->toImage().convertToFormat(format);
     unsigned int * srcData = (unsigned int *)srcImage.bits();
 
     // precalc the x correspondancy conversion in a lookup table
@@ -876,3 +879,6 @@ void PagePainter::drawShapeOnImage(
         painter.drawPath( path );
     }
 }
+
+/* kate: replace-tabs on; indent-width 4; */
+
